Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(36)

Unified Diff: components/crash/content/app/run_as_crashpad_handler_win.h

Issue 2867063002: Stability instrumentation Crashpad integration (Closed)
Patch Set: clang compile Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/crash/content/app/run_as_crashpad_handler_win.h
diff --git a/components/crash/content/app/run_as_crashpad_handler_win.h b/components/crash/content/app/run_as_crashpad_handler_win.h
index ade72a01db994c80bdd0c50eba7cc7d22522c980..2f2c090aa8fcf6942a72562bb0a624ceb42f5c12 100644
--- a/components/crash/content/app/run_as_crashpad_handler_win.h
+++ b/components/crash/content/app/run_as_crashpad_handler_win.h
@@ -7,20 +7,26 @@
namespace base {
class CommandLine;
+class FilePath;
}
namespace crash_reporter {
// Helper for running an embedded copy of crashpad_handler. Searches for and
// removes --(process_type_switch)=xyz arguments in the command line, and all
// options starting with '/' (for "/prefetch:N"), and then runs
// crashpad::HandlerMain with the remaining arguments.
//
// Normally, pass switches::kProcessType for process_type_switch. It's accepted
// as a parameter because this component does not have access to content/, where
// that variable lives.
int RunAsCrashpadHandler(const base::CommandLine& command_line,
- const char* process_type_switch);
+ const base::FilePath& user_data_dir,
+ const char* process_type_switch,
+ const char* user_data_dir_switch);
} // namespace crash_reporter

Powered by Google App Engine
@@ -7,20 +7,26 @@
namespace crash_reporter {
// Helper for running an embedded copy of crashpad_handler. Searches for and
-// removes --(process_type_switch)=xyz arguments in the command line, and all
-// options starting with '/' (for "/prefetch:N"), and then runs
-// crashpad::HandlerMain with the remaining arguments.
+// removes --(process_type_switch|user_data_dir_switch)=xyz arguments in the
+// command line, and all options starting with '/' (for "/prefetch:N"), and then
+// runs crashpad::HandlerMain with the remaining arguments. If user_data_dir is
+// non-empty, a Crashpad extension to collect stability instrumentation on crash
+// is used.
//
@@ -7,20 +7,26 @@
//
-// Normally, pass switches::kProcessType for process_type_switch. It's accepted
-// as a parameter because this component does not have access to content/, where
-// that variable lives.
+// Normally, pass switches::kProcessType and switches::kCrashpadHandler for
+// process_type_switch and user_data_dir_switch. These are accepted as
+// parameters because this component does not have access to content/, where
+// those variables live.
int RunAsCrashpadHandler(const base::CommandLine& command_line,
This is Rietveld 408576698